/* eslint-disable react-hooks/exhaustive-deps */
/* eslint-disable jsx-a11y/click-events-have-key-events */
/* eslint-disable import/no-extraneous-dependencies */
import React, { useContext, useEffect, useState } from 'react';
import PropTypes from 'prop-types';
import LazyImage from 'gatsby-core-theme/src/hooks/lazy-image';
import Sticky from '~molecules/sticky';
import Button from '~atoms/button/button';
import { translate } from '~helpers/getters';
import { Context } from '~context/MainProvider';
import { setCookie, getCookie } from '~helpers/cookies';
import isSticky from '~hooks/stickyOnScroll';
import CookieModal from '../../../../components/molecules/cookie-modal';
import styles from './cookie-consent.module.scss';

const CookieConsent = ({
  acceptText = 'Accept',
  location = 'bottom',
  showOnScroll = true,
  settingsCookie,
  settingsButtonType = 'secondary',
  isPageHomepage,
  buttonSize = 'm',
  type,
  cookieImage = '../../../images/cookie.png',
  children,
  cookieName = 'CookieConsent',
  logo = '../../../../../images/logo.svg',
}) => {
  const [showModal, setShowModal] = useState(false);
  const { translations, setCookieAccepted, cookieAccepted } = useContext(Context) || {};
  const sticky = isSticky();

  useEffect(() => {
    const getCk = getCookie(cookieName) === 'true' || false;
    setCookieAccepted(getCk);
  }, []);

  // when user declines
  const handleDecline = () => {
    setCookieAccepted(false);
    setCookie(cookieName, false, 365, '/');
    setShowModal(false);
  };

  // when user accepts
  const handleAccept = () => {
    setCookie(cookieName, true, 365, '/');
    setCookieAccepted(true);
    setShowModal(false);
  };

  return (
    <>
      {!cookieAccepted && (
        <Sticky
          showOnScroll={showOnScroll}
          className={`${styles?.cookieConsent || ''} ${type === 'operator' && styles.bottom}`}
          position={location}
        >
          <>
            <div className={styles?.content || ''}>{children}</div>
            <div className={styles?.buttonsContainer || ''}>
              {settingsCookie && (
                <Button
                  isInternalLink={false}
                  onClick={() => setShowModal(!showModal)}
                  btnText={translate(translations, 'cookie_setting_button', 'Cookie Setting')}
                  buttonType={settingsButtonType}
                  buttonSize={buttonSize}
                  gtmClass="cookie-consent-gtm btn-cta"
                />
              )}
              <Button
                onClick={() => handleAccept()}
                btnText={translate(translations, 'cookie_accept_button', acceptText)}
                isInternalLink={false}
                buttonType="primary"
                buttonSize={buttonSize}
                gtmClass="cookie-consent-gtm btn-cta"
              />
            </div>
          </>
        </Sticky>
      )}
      {settingsCookie && isPageHomepage && cookieAccepted && (
        <div
          role="button"
          tabIndex={0}
          className={styles.cookieButton}
          style={{ display: sticky ? 'flex' : 'none' }}
          onClick={() => setShowModal(true)}
        >
          <LazyImage src={cookieImage} alt="Cookie Button" width="32" height="32" loading="eager" />
        </div>
      )}

      {settingsCookie && (
        <CookieModal
          logo={logo}
          hide={!showModal}
          handleAcceptCookies={handleAccept}
          handleDeclineCookies={handleDecline}
          closeModal={setShowModal}
        />
      )}
    </>
  );
};

CookieConsent.propTypes = {
  acceptText: PropTypes.string,
  settingsCookie: PropTypes.bool,
  location: PropTypes.oneOf(['bottom', 'top']),
  type: PropTypes.string,
  cookieName: PropTypes.string,
  showOnScroll: PropTypes.bool,
  settingsButtonType: PropTypes.string,
  isPageHomepage: PropTypes.bool,
  buttonSize: PropTypes.string,
  cookieImage: PropTypes.string,
  logo: PropTypes.string,
  children: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.node), PropTypes.node, PropTypes.any]),
};

export default CookieConsent;
